#[repr(i32)]pub enum ModelType {
Unigram = 1,
Bpe = 2,
Word = 3,
Char = 4,
}Expand description
Model type.
Variants
Unigram = 1
Unigram language model with dynamic algorithm
Bpe = 2
Byte Pair Encoding
Word = 3
Delimitered by whitespace.
Char = 4
tokenizes into character sequence
Implementations
Sourceimpl ModelType
impl ModelType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.